==> drop_account-2.4.0.tar.gz: drop_account/l10n/nl.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) hebben hun account verwijderd",
    "%1$s (%2$s - %3$s) requested to delete their account. It has been disabled and will automatically be removed on %4$s" : "%1$s (%2$s - %3$s) heeft gevraagd om het account te verwijderen. Het is uitgeschakeld en zal automatisch worden verwijderd op %4$s",
    "Account %1$s (%2$s - %3$s) has been re-enabled by an admin" : "Account %1$s (%2$s - %3$s) is opnieuw ingeschakeld door een beheerder",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) hebben hun account verwijderd",
    "%1$s (%2$s) requested to delete their account. It has been disabled and will automatically be removed on %3$s" : "%1$s (%2$s) heeft gevraagd om het account te verwijderen. Het is uitgeschakeld en zal automatisch worden verwijderd op %3$s",
    "Account %1$s (%2$s) has been re-enabled by an admin" : "Account %1$s (%2$s) is opnieuw ingeschakeld door een beheerder",
    "%1$s deleted their account" : "%1$s hun account verwijderd",
    "%1$s requested to delete their account. It has been disabled and will automatically be removed on %2$s" : "Uw account is uitgeschakeld en de gegevens worden binnenkort verwijderd.",
    "Account %1$s has been re-enabled by an admin" : "Account %1$s is opnieuw ingeschakeld door een beheerder",
    "A user <strong>deleted</strong> its account" : "Een gebruiker <strong>verwijderde</strong> zijn account",
    "User session not found" : "Account niet gevonden.",
    "User-Session unexpectedly expired" : "Gebruikerssessie onverwacht verlopen",
    "Successfully sent email" : "E-mail succesvol verzonden",
    "You have no email set up into your account" : "Je hebt geen e-mail ingesteld in je account",
    "Unexpected error sending email. Please contact your administrator." : "Onverwachte fout bij het verzenden van e-mail. Neem contact op met uw beheerder.",
    "Confirm your account deletion on %s" : "Bevestig het verwijderen van uw account op %s",
    "Account deletion confirmation for %s" : "Bevestiging van accountverwijdering voor %s",
    "Hello," : "Hallo,",
    "Someone - probably you - asked to delete their account on %s." : "Iemand - waarschijnlijk jij - heeft gevraagd om jouw account op %s te verwijderen.",
    "To confirm the account deletion, you may click on the button below." : "Om het verwijderen van uw account te bevestigen, kunt u op de onderstaande knop klikken.",
    "If you didn't request this email, you should contact your administrator as soon as possible, someone may be accessing your account without your knowledge." : "Als je deze e-mail niet hebt aangevraagd, moet je zo snel mogelijk contact opnemen met je beheerder. Het is mogelijk dat iemand toegang heeft tot je account zonder dat je het weet.",
    "Delete account" : "Verwijder account",
    "Cheers!" : "Proost!",
    "User backend configuration does not allow deletion" : "Systeem instellingen voor gebruikers staat verwijderen niet toe",
    "You are the only user on the server, you can't delete your account." : "U bent de enige gebruiker van deze omgeving, u kunt uw account niet verwijderen.",
    "You are the only admin on the server, you can't delete your account." : "U bent de enige beheerder van deze omgeving, u kunt uw account niet verwijderen.",
    "Your account on %s has been disabled" : "Uw account op %s is uitgeschakeld",
    "Your account on %s has been deleted" : "Uw account op %s is verwijderd",
    "Account deletion on %s scheduled" : "Account verwijderen",
    "Account on %s deleted" : "Account verwijderen",
    "Hi," : "Hallo,",
    "_Your data will be permanently deleted in %n hour._::_Your data will be permanently deleted in %n hours._" : ["Uw gegevens worden permanent verwijderd over %n uur.","Uw gegevens worden permanent verwijderd over %n uur."],
    "_Your data will be permanently deleted in %n day, on %s._::_Your data will be permanently deleted in %n days, on %s._" : ["Uw gegevens worden permanent verwijderd over %n dag, op %s.","Uw gegevens worden permanent verwijderd over %n dagen, op %s."],
    "You can cancel your account deletion by contacting an administrator before the %s." : "U kunt de verwijdering van uw account annuleren door contact op te nemen met een beheerder vóór %s.",
    "We confirm all your personal data on %s was permanently deleted." : "We bevestigen dat al uw persoonlijke gegevens op %s permanent zijn verwijderd.",
    "Thanks for using our service." : "Bedankt voor het gebruik maken van onze dienst.",
    "Your account on %s has been reactivated" : "Uw account is op %s opnieuw geactiveerd",
    "Access to your account %1$s has been restored" : "Toegang tot uw account %1$s is hersteld",
    "An administrator re-enabled your account on %s before it was destroyed." : "Een beheerder heeft uw account opnieuw geactiveerd op %s voordat deze werd vernietigd.",
    "Your account is available again, none of your data was removed. You may now login again." : "Je account is weer beschikbaar, je gegevens zijn niet verwijderd. Je kunt nu weer aanmelden.",
    "Login" : "Aanmelden",
    "User account deletion" : "Gebruikersaccount verwijderen",
    "An app to allow users to delete their accounts." : "Een app waarmee gebruikers hun accounts kunnen verwijderen.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# Beschrijving\n\nMet deze app kunnen gebruikers hun accounts verwijderen door al hun gegevens te verwijderen.\n\nHet kan ook activiteiten naar de beheerders sturen over verwijderde accounts.",
    "Account deletion" : "Account verwijderen",
    "Allows users to delete themselves their own account." : "Hiermee kunnen gebruikers hun eigen account verwijderen.",
    "Email confirmation" : "E-mail bevestiging",
    "Require confirmation by email" : "Eis bevestiging per e-mail",
    "Will require users to click a confirmation link sent by email to confirm their action." : "Vereist dat gebruikers op een per e-mail verzonden bevestigingslink klikken om hun actie te bevestigen.",
    "Data purge" : "Gegevens verwijderen",
    "Users are not removed right away but disabled until a background job removes their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "Gebruikers worden niet direct verwijderd, maar uitgeschakeld totdat een achtergrondtaak deze gegevens voorgoed verwijderd. Ondertussen kunnen beheerders gebruikers \"redden\" door ze weer in te schakelen.",
    "Purge user data as soon as possible." : "Verwijder gebruikersgegevens zo snel mogelijk.",
    "Uses the next background job available to completely remove the user's data." : "Gebruikt de eerstvolgende achtergrondtaak om de gegevens van de gebruiker volledig te verwijderen.",
    "Purge user data after a while." : "Verwijder gebruikersgegevens na een tijdje.",
    "Deletes user data after a grace period." : "Verwijdert gebruikersgegevens na een bedenktijd.",
    "Grace period duration" : "Duur van de bedenktijd",
    "One day" : "Een dag",
    "One week" : "Een week",
    "One month" : "Een maand",
    "Error while changing require confirmation setting" : "Fout bij aanpassen van de vereiste instelling voor bevestiging",
    "Error while changing delay purge setting" : "Fout bij het aanpassen van de bedenktijd",
    "Error while changing delay purge hours setting" : "Fout bij het aanpassen van de instelling voor reinigingsuren",
    "Delete my account" : "Verwijder mijn account",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "Als u uw account verwijdert, worden al uw bestanden en gegevens verwijderd uit de apps die u gebruikt, zoals agenda en contacten.",
    "Account marked for deletion" : "Account gemarkeerd voor verwijderen",
    "Your account has been disabled and the data will be removed shortly." : "Uw account is uitgeschakeld en de gegevens worden binnenkort verwijderd.",
    "You are going to be redirected to the login page in a few seconds…" : "Je wordt binnen enkele seconden doorgestuurd naar de inlogpagina…",
    "Email confirmation required" : "Bevestiging per e-mail vereist",
    "Please click the link into the email we've just sent you to finish deleting your account." : "Klik op de link in de e-mail die we zojuist naar u hebben verstuurd om het verwijderen van uw account te voltooien.",
    "This action is irreversible!" : "Deze actie is onomkeerbaar!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "Nadat u de verwijdering van uw account heeft bevestigd, wordt u doorgestuurd naar de inlogpagina.",
    "You are the only user of this instance, you can't delete your account." : "U bent de enige gebruiker van deze omgeving, u kunt uw account niet verwijderen.",
    "You are the only admin of this instance, you can't delete your account." : "U bent de enige beheerder van deze omgeving, u kunt uw account niet verwijderen.",
    "An email confirmation is required by your admin to delete your account. Please fill your email in your personal settings first." : "Om uw account te verwijderen is door uw beheerder een bevestiging per e-mail vereist . Vul eerst uw e-mailadres in bij uw persoonlijke instellingen.",
    "Do you really wish to delete your account?" : "Wil je echt je account verwijderen?",
    "We will send you an email to confirm this action." : "We sturen je een e-mail om deze actie te bevestigen.",
    "Check this to confirm the deletion request" : "Vink dit aan om het verwijderingsverzoek te bevestigen",
    "Error while deleting the account" : "Fout bij het verwijderen van het account",
    "_This action will be reversible by an administrator for {nbDays} day after you request deletion._::_This action will be reversible by an administrator for {nbDays} days after you request deletion._" : ["Deze actie kan door een beheerder worden teruggedraaid tot {nbDagen} dag nadat je het verwijderen hebt aangevraagd.","Deze actie kan tot {nbDagen} nadat je het verwijderen hebt aangevraagd door een beheerder ongedaan worden gemaakt."],
    "Your account has been marked for deletion. You can now close this window." : "Uw account is gemarkeerd voor verwijdering. U kunt dit venster nu sluiten.",
    "Account not found." : "Account niet gevonden.",
    "The token provided was not found." : "Het opgegeven token is niet gevonden.",
    "Make sure the link opened is valid or that you are logged-in with the correct user." : "Controleer of de geopende link geldig is of dat je bent aangemeld met de juiste gebruiker.",
    "Back to %s" : "Terug naar %s",
    "Unknown error." : "Onbekende fout."
},
"nplurals=2; plural=n != 1;");

==> drop_account-2.6.1.tar.gz: drop_account/l10n/nl.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) hebben hun account verwijderd",
    "%1$s (%2$s - %3$s) requested to delete their account. It has been disabled and will automatically be removed on %4$s" : "%1$s (%2$s - %3$s) heeft gevraagd om het account te verwijderen. Het is uitgeschakeld en zal automatisch worden verwijderd op %4$s",
    "Account %1$s (%2$s - %3$s) has been re-enabled by an admin" : "Account %1$s (%2$s - %3$s) is opnieuw ingeschakeld door een beheerder",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) hebben hun account verwijderd",
    "%1$s (%2$s) requested to delete their account. It has been disabled and will automatically be removed on %3$s" : "%1$s (%2$s) heeft gevraagd om het account te verwijderen. Het is uitgeschakeld en zal automatisch worden verwijderd op %3$s",
    "Account %1$s (%2$s) has been re-enabled by an admin" : "Account %1$s (%2$s) is opnieuw ingeschakeld door een beheerder",
    "%1$s deleted their account" : "%1$s hun account verwijderd",
    "%1$s requested to delete their account. It has been disabled and will automatically be removed on %2$s" : "%1$s heeft gevraagd om het account te verwijderen. Het is uitgeschakeld en zal automatisch worden verwijderd op %2$s",
    "Account %1$s has been re-enabled by an admin" : "Account %1$s is opnieuw ingeschakeld door een beheerder",
    "A user <strong>deleted</strong> its account" : "Een gebruiker heeft het gebruikte account <strong>verwijderd</strong>",
    "User session not found" : "Gebruikerssessie niet gevonden",
    "User-Session unexpectedly expired" : "Gebruikerssessie onverwacht verlopen",
    "Successfully sent email" : "E-mail succesvol verzonden",
    "You have no email set up into your account" : "Je hebt geen e-mail ingesteld in je account",
    "Unexpected error sending email. Please contact your administrator." : "Onverwachte fout bij het verzenden van e-mail. Neem contact op met uw beheerder.",
    "Confirm your account deletion on %s" : "Bevestig het verwijderen van uw account op %s",
    "Account deletion confirmation for %s" : "Bevestiging van accountverwijdering voor %s",
    "Hello," : "Hallo,",
    "Someone - probably you - asked to delete their account on %s." : "Iemand - waarschijnlijk jij - heeft gevraagd om jouw account op %s te verwijderen.",
    "To confirm the account deletion, you may click on the button below." : "Om het verwijderen van uw account te bevestigen, kunt u op de onderstaande knop klikken.",
    "If you didn't request this email, you should contact your administrator as soon as possible, someone may be accessing your account without your knowledge." : "Als je deze e-mail niet hebt aangevraagd, moet je zo snel mogelijk contact opnemen met je beheerder. Het is mogelijk dat iemand toegang heeft tot je account zonder dat je het weet.",
    "Delete account" : "Verwijder account",
    "Cheers!" : "Proost!",
    "User backend configuration does not allow deletion" : "Systeem instellingen voor gebruikers staat verwijderen niet toe",
    "You are the only user on the server, you can't delete your account." : "U bent de enige gebruiker op de server, account kan niet worden verwijderen.",
    "You are the only admin on the server, you can't delete your account." : "U bent de enige beheerder op de server, het account kan niet worden verwijderen.",
    "Your account on %s has been disabled" : "Uw account op %s is uitgeschakeld",
    "Your account on %s has been deleted" : "Uw account op %s is verwijderd",
    "Account deletion on %s scheduled" : "Account verwijderen op %s gepland",
    "Account on %s deleted" : "Account op %s verwijderd",
    "Hi," : "Hallo,",
    "_Your data will be permanently deleted in %n hour._::_Your data will be permanently deleted in %n hours._" : ["Uw gegevens worden permanent verwijderd over %n uur.","Uw gegevens worden permanent verwijderd over %n uur."],
    "_Your data will be permanently deleted in %n day, on %s._::_Your data will be permanently deleted in %n days, on %s._" : ["Uw gegevens worden permanent verwijderd over %n dag, op %s.","Uw gegevens worden permanent verwijderd over %n dagen, op %s."],
    "You can cancel your account deletion by contacting an administrator before the %s." : "U kunt de verwijdering van uw account annuleren door contact op te nemen met een beheerder vóór %s.",
    "We confirm all your personal data on %s was permanently deleted." : "We bevestigen dat al uw persoonlijke gegevens op %s permanent zijn verwijderd.",
    "Thanks for using our service." : "Bedankt voor het gebruik maken van onze dienst.",
    "Your account on %s has been reactivated" : "Uw account is op %s opnieuw geactiveerd",
    "Access to your account %1$s has been restored" : "Toegang tot uw account %1$s is hersteld",
    "An administrator re-enabled your account on %s before it was destroyed." : "Een beheerder heeft uw account opnieuw geactiveerd op %s voordat deze werd vernietigd.",
    "Your account is available again, none of your data was removed. You may now login again." : "Je account is weer beschikbaar, je gegevens zijn niet verwijderd. Je kunt nu weer aanmelden.",
    "Login" : "Aanmelden",
    "User account deletion" : "Gebruikersaccount verwijderen",
    "An app to allow users to delete their accounts." : "Een app waarmee gebruikers hun accounts kunnen verwijderen.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# Beschrijving\n\nMet deze app kunnen gebruikers hun accounts verwijderen door al hun gegevens te verwijderen.\n\nHet kan ook activiteiten naar de beheerders sturen over verwijderde accounts.",
    "Account deletion" : "Account verwijderen",
    "Allows users to delete themselves their own account." : "Hiermee kunnen gebruikers hun eigen account verwijderen.",
    "Email confirmation" : "E-mail bevestiging",
    "Require confirmation by email" : "Eis bevestiging per e-mail",
    "Will require users to click a confirmation link sent by email to confirm their action." : "Vereist dat gebruikers op een per e-mail verzonden bevestigingslink klikken om hun actie te bevestigen.",
    "Data purge" : "Gegevens verwijderen",
    "Users are not removed right away but disabled until a background job removes their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "Gebruikers worden niet meteen verwijderd, maar uitgeschakeld totdat een achtergrondtaak hun gegevens definitief verwijdert. In de tussentijd kunnen beheerders gebruikers \"redden\" door het account weer in te schakelen.",
    "Purge user data as soon as possible." : "Verwijder gebruikersgegevens zo snel mogelijk.",
    "Purge user data after a while." : "Verwijder gebruikersgegevens na een tijdje.",
    "Deletes user data after a grace period." : "Verwijdert gebruikersgegevens na een bedenktijd.",
    "Grace period duration" : "Duur van de bedenktijd",
    "One day" : "Een dag",
    "One week" : "Een week",
    "One month" : "Een maand",
    "Error while changing require confirmation setting" : "Fout bij aanpassen van de vereiste instelling voor bevestiging",
    "Error while changing delay purge setting" : "Fout bij het aanpassen van de bedenktijd",
    "Error while changing delay purge hours setting" : "Fout bij het aanpassen van de instelling voor reinigingsuren",
    "Delete my account" : "Verwijder mijn account",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "Als u uw account verwijdert, worden al uw bestanden en gegevens verwijderd uit de apps die u gebruikt, zoals agenda en contacten.",
    "Account marked for deletion" : "Account gemarkeerd voor verwijderen",
    "Your account has been disabled and the data will be removed shortly." : "Uw account is uitgeschakeld en de gegevens worden binnenkort verwijderd.",
    "You are going to be redirected to the login page in a few seconds…" : "Je wordt binnen enkele seconden doorgestuurd naar de inlogpagina…",
    "Email confirmation required" : "Bevestiging per e-mail vereist",
    "This action is irreversible!" : "Deze actie is onomkeerbaar!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "Nadat u de verwijdering van uw account heeft bevestigd, wordt u doorgestuurd naar de inlogpagina.",
    "An email confirmation is required by your admin to delete your account. Please fill your email in your personal settings first." : "Om uw account te verwijderen is door uw beheerder een bevestiging per e-mail vereist . Vul eerst uw e-mailadres in bij uw persoonlijke instellingen.",
    "Do you really wish to delete your account?" : "Wil je echt je account verwijderen?",
    "We will send you an email to confirm this action." : "We sturen je een e-mail om deze actie te bevestigen.",
    "Check this to confirm the deletion request" : "Vink dit aan om het verwijderingsverzoek te bevestigen",
    "Error while deleting the account" : "Fout bij het verwijderen van het account",
    "_This action will be reversible by an administrator for {nbDays} day after you request deletion._::_This action will be reversible by an administrator for {nbDays} days after you request deletion._" : ["Deze actie kan door een beheerder worden teruggedraaid tot {nbDagen} dag nadat je het verwijderen hebt aangevraagd.","Deze actie kan tot {nbDagen} nadat je het verwijderen hebt aangevraagd door een beheerder ongedaan worden gemaakt."],
    "Your account has been marked for deletion. You can now close this window." : "Uw account is gemarkeerd voor verwijdering. U kunt dit venster nu sluiten.",
    "Account not found." : "Account niet gevonden.",
    "The token provided was not found." : "Het opgegeven token is niet gevonden.",
    "Make sure the link opened is valid or that you are logged-in with the correct user." : "Controleer of de geopende link geldig is of dat je bent aangemeld met de juiste gebruiker.",
    "Back to %s" : "Terug naar %s",
    "Unknown error." : "Onbekende fout."
},
"nplurals=2; plural=n != 1;");
